<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>Csak most</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 új üzenet</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 perccel ezelőtt</translation>
    </message>
</context>
</TS>